@@ -81,7 +81,9 @@ class GrimoirePage:
         else:
             url_to_run = [url]
 
-        with alive_bar((len(url_to_run)*len(command_to_run)), bar="filling") as bar:
+        with alive_bar(
+            (len(url_to_run) * len(command_to_run)), bar="filling"
+        ) as bar:
 
             for url in url_to_run:
                 for command in command_to_run:
