@@ -57,9 +57,12 @@ class SSLVerify(Plugin):
         except socket.timeout:
             output_strng = broken_response(url)
         else:
+            self.logger.info(
+                f"will_expire {will_expire_in}, limit {limit}, today {datetime.datetime.now()}"
+            )
             if will_expire_in is None:
                 output_strng = broken_response(url)
-            elif will_expire_in < limit:
+            elif will_expire_in < datetime.datetime.now():
                 output_strng = {
                     "status": "KO",
                     "expired": str(will_expire_in),
@@ -85,12 +88,18 @@ class SSLVerify(Plugin):
             stat = {"OK": 0, "KO": 0, "XX": 0}
             stat[data[directive]["status"]] = 1
             other = {}
-            if data[directive]["status"] != "OK":
+            if data[directive]["status"] == "KO":
                 other = {
                     colored(data[directive]["domain"], "red"): colored(
                         data[directive]["expired"], "red"
                     )
                 }
+            elif data[directive]["status"] == "XX":
+                other = {
+                    colored(data[directive]["domain"], "yellow"): colored(
+                        data[directive]["expired"], "yellow"
+                    )
+                }
             return stat, other
         except KeyError as e:
             self.logger.error(str(e))
